var wxwidgets_8h =
[
    [ "Font", "classFont.html", "classFont" ],
    [ "FontGrabber", "classFontGrabber.html", "classFontGrabber" ],
    [ "PlDevice", "classPlDevice.html", "classPlDevice" ],
    [ "wxPLDevice", "classwxPLDevice.html", "classwxPLDevice" ],
    [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
    [ "Log_Debug", "wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b", null ],
    [ "Log_Verbose", "wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15", null ],
    [ "operator==", "wxwidgets_8h.html#a1cc916f725de04817aeb2ae4aea4a14d", null ],
    [ "plD_bop_wxwidgets", "wxwidgets_8h.html#ad74eeaa5e1922ea1fab185786c172be0", null ],
    [ "plD_eop_wxwidgets", "wxwidgets_8h.html#a28455e43dfd0a1ed3c5f70f5954ee4e0", null ],
    [ "plD_esc_wxwidgets", "wxwidgets_8h.html#a2df717037e3fd4ca9084c6cd1fd72229", null ],
    [ "plD_init_wxpng", "wxwidgets_8h.html#a4798081d428df271b10ddaae05435b21", null ],
    [ "plD_init_wxwidgets", "wxwidgets_8h.html#a3a8644936ef24419143cb7a474c667b7", null ],
    [ "plD_line_wxwidgets", "wxwidgets_8h.html#ac08215d27d48f5b67d4c822f3f4be18e", null ],
    [ "plD_polyline_wxwidgets", "wxwidgets_8h.html#ae2496920c4414c0d73a2d99a84847c84", null ],
    [ "plD_state_wxwidgets", "wxwidgets_8h.html#aa0cabe346e76ee92fa71432d75e24484", null ],
    [ "plD_tidy_wxwidgets", "wxwidgets_8h.html#a282d423773fa7d99a0309081a594ca27", null ],
    [ "wx_set_buffer", "wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003", null ],
    [ "wx_set_dc", "wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f", null ],
    [ "fontFamilyLookup", "wxwidgets_8h.html#a98e63d912a13da0ed2a2568547e55479", null ],
    [ "fontStyleLookup", "wxwidgets_8h.html#a9527465bcb32eac9a8b9d7f58567e825", null ],
    [ "fontWeightLookup", "wxwidgets_8h.html#a9f01825db2b4a454b7c875fe6cd7c385", null ]
];